@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2004, 2006, 2008, 2009, 2010 Free Software
+ * Copyright (C) 2002, 2004, 2006, 2008, 2009, 2010, 2011 Free Software
  * Foundation, Inc.
  *
  * This file is part of LIBTASN1.
@@ -54,7 +54,7 @@ _asn1_error_description_tag_error (ASN1_TYPE node, char *ErrorDescription)
  *
  * Extract a length field from DER data.
  *
- * Return value: Return the decoded length value, or -1 on indefinite
+ * Returns: Return the decoded length value, or -1 on indefinite
  *   length, or -2 when the value was too big.
  **/
 signed long
@@ -101,7 +101,6 @@ asn1_get_length_der (const unsigned char *der, int der_len, int *len)
     }
 }
 
-
 /**
  * asn1_get_tag_der:
  * @der: DER data to decode.
@@ -112,7 +111,7 @@ asn1_get_length_der (const unsigned char *der, int der_len, int *len)
  *
  * Decode the class and TAG from DER code.
  *
- * Return value: Returns %ASN1_SUCCESS on success, or an error.
+ * Returns: Returns %ASN1_SUCCESS on success, or an error.
  **/
 int
 asn1_get_tag_der (const unsigned char *der, int der_len,
@@ -169,8 +168,8 @@ asn1_get_tag_der (const unsigned char *der, int der_len,
  * asn1_get_length_der() is that this function will return a length
  * even if the value has indefinite encoding.
  *
- * Return value: Return the decoded length value, or negative value
- *   when the value was too big.
+ * Returns: Return the decoded length value, or negative value when
+ *   the value was too big.
  *
  * Since: 2.0
  **/
@@ -203,7 +202,7 @@ asn1_get_length_ber (const unsigned char *ber, int ber_len, int *len)
  *
  * Extract an OCTET SEQUENCE from DER data.
  *
- * Return value: Returns %ASN1_SUCCESS on success, or an error.
+ * Returns: Returns %ASN1_SUCCESS on success, or an error.
  **/
 int
 asn1_get_octet_der (const unsigned char *der, int der_len,
@@ -232,8 +231,6 @@ asn1_get_octet_der (const unsigned char *der, int der_len,
   return ASN1_SUCCESS;
 }
 
-
-
 /* Returns ASN1_SUCCESS on success or an error code on error.
  */
 static int
@@ -254,8 +251,6 @@ _asn1_get_time_der (const unsigned char *der, int der_len, int *ret_len,
   return ASN1_SUCCESS;
 }
 
-
-
 static int
 _asn1_get_objectid_der (const unsigned char *der, int der_len, int *ret_len,
 			char *str, int str_size)
@@ -288,18 +283,18 @@ _asn1_get_objectid_der (const unsigned char *der, int der_len, int *ret_len,
   leading = 1;
   for (k = 1; k < len; k++)
     {
-      
-
       /* X.690 mandates that the leading byte must never be 0x80
        */
-      if (leading != 0 && der[len_len + k] == 0x80) return ASN1_DER_ERROR;
+      if (leading != 0 && der[len_len + k] == 0x80)
+	return ASN1_DER_ERROR;
       leading = 0;
 
       /* check for wrap around */
       val = val << 7;
       val |= der[len_len + k] & 0x7F;
 
-      if (val < prev_val) return ASN1_DER_ERROR;
+      if (val < prev_val)
+	return ASN1_DER_ERROR;
 
       prev_val = val;
 
@@ -313,7 +308,7 @@ _asn1_get_objectid_der (const unsigned char *der, int der_len, int *ret_len,
 	}
     }
   *ret_len = len + len_len;
-  
+
   return ASN1_SUCCESS;
 }
 
@@ -328,7 +323,7 @@ _asn1_get_objectid_der (const unsigned char *der, int der_len, int *ret_len,
  *
  * Extract a BIT SEQUENCE from DER data.
  *
- * Return value: Return %ASN1_SUCCESS on success, or an error.
+ * Returns: Return %ASN1_SUCCESS on success, or an error.
  **/
 int
 asn1_get_bit_der (const unsigned char *der, int der_len,
@@ -356,9 +351,6 @@ asn1_get_bit_der (const unsigned char *der, int der_len,
   return ASN1_SUCCESS;
 }
 
-
-
-
 static int
 _asn1_extract_tag_der (ASN1_TYPE node, const unsigned char *der, int der_len,
 		       int *ret_len)
@@ -557,7 +549,6 @@ _asn1_extract_tag_der (ASN1_TYPE node, const unsigned char *der, int der_len,
   return ASN1_SUCCESS;
 }
 
-
 static int
 _asn1_delete_not_used (ASN1_TYPE node)
 {
@@ -662,7 +653,6 @@ _asn1_extract_der_octet (ASN1_TYPE node, const unsigned char *der,
   return ASN1_SUCCESS;
 }
 
-
 static asn1_retCode
 _asn1_get_octet_string (const unsigned char *der, ASN1_TYPE node, int *len)
 {
@@ -796,7 +786,6 @@ _asn1_get_indefinite_length_string (const unsigned char *der, int *len)
 
 }
 
-
 /**
  * asn1_der_decoding:
  * @element: pointer to an ASN1 structure.
@@ -805,20 +794,16 @@ _asn1_get_indefinite_length_string (const unsigned char *der, int *len)
  * @errorDescription: null-terminated string contains details when an
  *   error occurred.
  *
- * Fill the structure *ELEMENT with values of a DER encoding
+ * Fill the structure *@ELEMENT with values of a DER encoding
  * string. The structure must just be created with function
- * 'asn1_create_element'.  If an error occurs during the decoding
- * procedure, the *ELEMENT is deleted and set equal to
+ * asn1_create_element().  If an error occurs during the decoding
+ * procedure, the *@ELEMENT is deleted and set equal to
  * %ASN1_TYPE_EMPTY.
  *
- * Returns:
- *
- *   %ASN1_SUCCESS: DER encoding OK.
- *
- *   %ASN1_ELEMENT_NOT_FOUND: ELEMENT is ASN1_TYPE_EMPTY.
- *
- *   %ASN1_TAG_ERROR,ASN1_DER_ERROR: The der encoding doesn't match
- *     the structure NAME. *ELEMENT deleted.
+ * Returns: %ASN1_SUCCESS if DER encoding OK, %ASN1_ELEMENT_NOT_FOUND
+ *   if @ELEMENT is %ASN1_TYPE_EMPTY, and %ASN1_TAG_ERROR or
+ *   %ASN1_DER_ERROR if the der encoding doesn't match the structure
+ *   name (*@ELEMENT deleted).
  **/
 asn1_retCode
 asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
@@ -854,7 +839,7 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	  if (p->type & CONST_SET)
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (len2 == -1)
 		{
 		  if (!der[counter] && !der[counter + 1])
@@ -917,7 +902,7 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	  if ((p->type & CONST_OPTION) || (p->type & CONST_DEFAULT))
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (counter == len2)
 		{
 		  if (p->right)
@@ -982,7 +967,7 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	  if ((p->type & CONST_OPTION) || (p->type & CONST_DEFAULT))
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if ((len2 != -1) && (counter > len2))
 		ris = ASN1_TAG_ERROR;
 	    }
@@ -1053,8 +1038,9 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	      move = RIGHT;
 	      break;
 	    case TYPE_OBJECT_ID:
-	      result = _asn1_get_objectid_der (der + counter, len - counter, &len2,
-				      temp, sizeof (temp));
+	      result =
+		_asn1_get_objectid_der (der + counter, len - counter, &len2,
+					temp, sizeof (temp));
 	      if (result != ASN1_SUCCESS)
 		{
 		  asn1_delete_structure (element);
@@ -1116,7 +1102,7 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	    case TYPE_SET:
 	      if (move == UP)
 		{
-		  len2 = strtol (p->value, NULL, 10);
+		  len2 = _asn1_strtol (p->value, NULL, 10);
 		  _asn1_set_value (p, NULL, 0);
 		  if (len2 == -1)
 		    {		/* indefinite length method */
@@ -1184,7 +1170,7 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
 	    case TYPE_SET_OF:
 	      if (move == UP)
 		{
-		  len2 = strtol (p->value, NULL, 10);
+		  len2 = _asn1_strtol (p->value, NULL, 10);
 		  if (len2 == -1)
 		    {		/* indefinite length method */
 		      if ((counter + 2) > len)
@@ -1347,7 +1333,6 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
   return ASN1_SUCCESS;
 }
 
-
 #define FOUND        1
 #define SAME_BRANCH  2
 #define OTHER_BRANCH 3
@@ -1362,22 +1347,17 @@ asn1_der_decoding (ASN1_TYPE * element, const void *ider, int len,
  * @errorDescription: null-terminated string contains details when an
  *   error occurred.
  *
- * Fill the element named ELEMENTNAME with values of a DER encoding
+ * Fill the element named @ELEMENTNAME with values of a DER encoding
  * string.  The structure must just be created with function
- * 'asn1_create_element'.  The DER vector must contain the encoding
- * string of the whole STRUCTURE.  If an error occurs during the
- * decoding procedure, the *STRUCTURE is deleted and set equal to
+ * asn1_create_element().  The DER vector must contain the encoding
+ * string of the whole @STRUCTURE.  If an error occurs during the
+ * decoding procedure, the *@STRUCTURE is deleted and set equal to
  * %ASN1_TYPE_EMPTY.
  *
- * Returns:
- *
- *   %ASN1_SUCCESS: DER encoding OK.
- *
- *   %ASN1_ELEMENT_NOT_FOUND: ELEMENT is ASN1_TYPE_EMPTY or
- *     elementName == NULL.
- *
- *   %ASN1_TAG_ERROR,ASN1_DER_ERROR: The der encoding doesn't match
- *   the structure STRUCTURE. *ELEMENT deleted.
+ * Returns: %ASN1_SUCCESS if DER encoding OK, %ASN1_ELEMENT_NOT_FOUND
+ *   if ELEMENT is %ASN1_TYPE_EMPTY or @elementName == NULL, and
+ *   %ASN1_TAG_ERROR or %ASN1_DER_ERROR if the der encoding doesn't
+ *   match the structure @structure (*ELEMENT deleted).
  **/
 asn1_retCode
 asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
@@ -1387,7 +1367,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
   char temp[128], currentName[ASN1_MAX_NAME_SIZE * 10], *dot_p, *char_p;
   int nameLen = ASN1_MAX_NAME_SIZE * 10 - 1, state;
   int counter, len2, len3, len4, move, ris, tlen;
-  unsigned char class, *temp2;
+  unsigned char class;
   unsigned long tag;
   int indefinite, result;
   const unsigned char *der = ider;
@@ -1456,7 +1436,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	  if (p->type & CONST_SET)
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (counter == len2)
 		{
 		  p = p2;
@@ -1509,7 +1489,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	  if ((p->type & CONST_OPTION) || (p->type & CONST_DEFAULT))
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (counter == len2)
 		{
 		  if (p->right)
@@ -1574,7 +1554,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	  if ((p->type & CONST_OPTION) || (p->type & CONST_DEFAULT))
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (counter > len2)
 		ris = ASN1_TAG_ERROR;
 	    }
@@ -1668,12 +1648,13 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	    case TYPE_OBJECT_ID:
 	      if (state == FOUND)
 		{
-		  result = _asn1_get_objectid_der (der + counter, len - counter, &len2,
-					  temp, sizeof (temp));
-                  if (result != ASN1_SUCCESS)
-                  {
-		    return result;
-                  }
+		  result =
+		    _asn1_get_objectid_der (der + counter, len - counter,
+					    &len2, temp, sizeof (temp));
+		  if (result != ASN1_SUCCESS)
+		    {
+		      return result;
+		    }
 
 		  tlen = strlen (temp);
 
@@ -1780,7 +1761,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	    case TYPE_SET:
 	      if (move == UP)
 		{
-		  len2 = strtol (p->value, NULL, 10);
+		  len2 = _asn1_strtol (p->value, NULL, 10);
 		  _asn1_set_value (p, NULL, 0);
 		  if (len2 == -1)
 		    {		/* indefinite length method */
@@ -1860,7 +1841,7 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 	    case TYPE_SET_OF:
 	      if (move == UP)
 		{
-		  len2 = strtol (p->value, NULL, 10);
+		  len2 = _asn1_strtol (p->value, NULL, 10);
 		  if (len2 > counter)
 		    {
 		      _asn1_append_sequence_set (p);
@@ -1940,7 +1921,6 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
 		  if (state == FOUND)
 		    {
 		      _asn1_set_value_octet (p, der + counter, len2 + len3);
-		      temp2 = NULL;
 
 		      if (p == nodeFound)
 			state = EXIT;
@@ -2123,8 +2103,6 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
   return ASN1_SUCCESS;
 }
 
-
-
 /**
  * asn1_der_decoding_startEnd:
  * @element: pointer to an ASN1 element
@@ -2138,21 +2116,17 @@ asn1_der_decoding_element (ASN1_TYPE * structure, const char *elementName,
  *
  * Find the start and end point of an element in a DER encoding
  * string. I mean that if you have a der encoding and you have already
- * used the function "asn1_der_decoding" to fill a structure, it may
+ * used the function asn1_der_decoding() to fill a structure, it may
  * happen that you want to find the piece of string concerning an
  * element of the structure.
  *
- * Example: the sequence "tbsCertificate" inside an X509 certificate.
+ * One example is the sequence "tbsCertificate" inside an X509
+ * certificate.
  *
- * Returns:
- *
- *   %ASN1_SUCCESS: DER encoding OK.
- *
- *   %ASN1_ELEMENT_NOT_FOUND: ELEMENT is ASN1_TYPE EMPTY or
- *   NAME_ELEMENT is not a valid element.
- *
- *   %ASN1_TAG_ERROR,ASN1_DER_ERROR: the der encoding doesn't match
- *   the structure ELEMENT.
+ * Returns: %ASN1_SUCCESS if DER encoding OK, %ASN1_ELEMENT_NOT_FOUND
+ *   if ELEMENT is %ASN1_TYPE EMPTY or @name_element is not a valid
+ *   element, %ASN1_TAG_ERROR or %ASN1_DER_ERROR if the der encoding
+ *   doesn't match the structure ELEMENT.
  **/
 asn1_retCode
 asn1_der_decoding_startEnd (ASN1_TYPE element, const void *ider, int len,
@@ -2197,7 +2171,7 @@ asn1_der_decoding_startEnd (ASN1_TYPE element, const void *ider, int len,
 	  if (p->type & CONST_SET)
 	    {
 	      p2 = _asn1_find_up (p);
-	      len2 = strtol (p2->value, NULL, 10);
+	      len2 = _asn1_strtol (p2->value, NULL, 10);
 	      if (len2 == -1)
 		{
 		  if (!der[counter] && !der[counter + 1])
@@ -2475,7 +2449,6 @@ asn1_der_decoding_startEnd (ASN1_TYPE element, const void *ider, int len,
   return ASN1_ELEMENT_NOT_FOUND;
 }
 
-
 /**
  * asn1_expand_any_defined_by:
  * @definitions: ASN1 definitions
@@ -2487,14 +2460,10 @@ asn1_der_decoding_startEnd (ASN1_TYPE element, const void *ider, int len,
  * expand the element ANY is the first one following the definition of
  * the actual value of the OBJECT IDENTIFIER.
  *
- * Returns:
- *
- *   %ASN1_SUCCESS: Substitution OK.
- *
- *   %ASN1_ERROR_TYPE_ANY: Some "ANY DEFINED BY" element couldn't be
- *   expanded due to a problem in OBJECT_ID -> TYPE association.
- *
- *   other errors: Result of der decoding process.
+ * Returns: %ASN1_SUCCESS if Substitution OK, %ASN1_ERROR_TYPE_ANY if
+ *   some "ANY DEFINED BY" element couldn't be expanded due to a
+ *   problem in OBJECT_ID -> TYPE association, or other error codes
+ *   depending on DER decoding.
  **/
 asn1_retCode
 asn1_expand_any_defined_by (ASN1_TYPE definitions, ASN1_TYPE * element)
@@ -2593,9 +2562,9 @@ asn1_expand_any_defined_by (ASN1_TYPE definitions, ASN1_TYPE * element)
 			asn1_read_value (definitions, name, value, &len);
 
 		      if ((result == ASN1_SUCCESS)
-			  && (!strcmp (p3->value, value)))
+			  && (!_asn1_strcmp (p3->value, value)))
 			{
-			  p2 = p2->right;	/* pointer to the structure to 
+			  p2 = p2->right;	/* pointer to the structure to
 						   use for expansion */
 			  while ((p2) && (p2->type & CONST_ASSIGN))
 			    p2 = p2->right;
@@ -2708,8 +2677,6 @@ asn1_expand_any_defined_by (ASN1_TYPE definitions, ASN1_TYPE * element)
   return retCode;
 }
 
-
-
 /**
  * asn1_expand_octet_string:
  * @definitions: ASN1 definitions
@@ -2719,20 +2686,14 @@ asn1_expand_any_defined_by (ASN1_TYPE definitions, ASN1_TYPE * element)
  *    the type for expansion.
  *
  * Expands an "OCTET STRING" element of a structure created from a DER
- * decoding process (asn1_der_decoding function). The type used for
- * expansion is the first one following the definition of the actual
- * value of the OBJECT IDENTIFIER indicated by OBJECTNAME.
+ * decoding process (the asn1_der_decoding() function).  The type used
+ * for expansion is the first one following the definition of the
+ * actual value of the OBJECT IDENTIFIER indicated by OBJECTNAME.
  *
- * Returns:
- *
- *   %ASN1_SUCCESS: Substitution OK.
- *
- *   %ASN1_ELEMENT_NOT_FOUND: @objectName or @octetName are not correct.
- *
- *   %ASN1_VALUE_NOT_VALID: Wasn't possible to find the type to use
- *       for expansion.
- *
- *   other errors: result of der decoding process.
+ * Returns: %ASN1_SUCCESS if substitution OK, %ASN1_ELEMENT_NOT_FOUND
+ *   if @objectName or @octetName are not correct,
+ *   %ASN1_VALUE_NOT_VALID if it wasn't possible to find the type to
+ *   use for expansion, or other errors depending on DER decoding.
  **/
 asn1_retCode
 asn1_expand_octet_string (ASN1_TYPE definitions, ASN1_TYPE * element,
@@ -2782,10 +2743,10 @@ asn1_expand_octet_string (ASN1_TYPE definitions, ASN1_TYPE * element,
 	  result = asn1_read_value (definitions, name, value, &len);
 
 	  if ((result == ASN1_SUCCESS)
-	      && (!strcmp (objectNode->value, value)))
+	      && (!_asn1_strcmp (objectNode->value, value)))
 	    {
 
-	      p2 = p2->right;	/* pointer to the structure to 
+	      p2 = p2->right;	/* pointer to the structure to
 				   use for expansion */
 	      while ((p2) && (p2->type & CONST_ASSIGN))
 		p2 = p2->right;
