@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010 Free Software
+ * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
  * Foundation, Inc.
  *
  * This file is part of LIBTASN1.
@@ -104,7 +104,7 @@ main (int argc, char *argv[])
   if (result != ASN1_SUCCESS)
     {
       asn1_perror (result);
-      printf ("Cannot decode BER data (size %d)\n", size);
+      printf ("Cannot decode BER data (size %ld)\n", size);
       exit (1);
     }
 
